
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

###########################
Sample usage for featstruct
###########################

.. include:: ../../nltk/test/featstruct.doctest